# Graphene Modeling

![](https://github.com/gholdman1/graphenemodeling/blob/master/notebooks/Graphene/images/overview.png)

This Python package models the electronic and optical properties of graphene and is accompanied by Jupyter notebooks.

**Install** the latest version with `pip install graphenemodeling`  or by downloading and building from source.

**Test** your installation with the command

```
> python -m graphenemodeling
```

You should see the greeting

```
	Welcome to graphenemodeling version #.#.#!

    For a quick overview of this package's capabilities, run
    > python -m graphenemodeling overview

    For issues, contact Gregory Holdman at gholdman@protonmail.com
    or submit an issue or pull request on github.

```

**Learn** how to use this package by following along with the Jupyter notebooks in the `notebooks` directory. You can obtain these by cloning the git repository.